@@ -327,7 +327,7 @@ class AegisHandler(tornado.web.RequestHandler):
             if not cookie_durations:
                 cookie_durations = {'user': 3650, 'session': None, 'auth': 90}
             cookie_duration = cookie_durations[name]
-        cookie_flags = {'httponly': True, 'secure': True}
+        cookie_flags = {'httponly': True, 'secure': True, 'samesite': 'Lax'}
         if options.hostname == 'localhost':
             cookie_flags['secure'] = False
         # XXX Way to not set httponly for reading in javascript
@@ -799,6 +799,7 @@ class AegisApplication():
         settings = dict(
             cookie_secret=options.cookie_secret,
             xsrf_cookies=True,
+            xsrf_cookie_kwargs=dict(httponly=True, secure=True, samesite='Strict'),
             login_url='/login',
             debug=options.app_debug
         )
@@ -979,7 +980,11 @@ class AegisHydra(AegisWeb):
         self.tmpl['hydra_types'] = aegis.model.HydraType.scan()
         self.tmpl['home_link'] = '/'
         self.tmpl['aegis_version'] = pkg_resources.require("aegis-tools")[0].version
-        self.tmpl['app_version'] = pkg_resources.require(aegis.config.get('program_name'))[0].version
+        try:
+            self.tmpl['app_version'] = pkg_resources.require(aegis.config.get('program_name'))[0].version
+        except pkg_resources.ContextualVersionConflict as ex:
+            logging.exception(ex)
+            self.tmpl['app_version'] = 'N/A'
         return self.render_path("hydra.html", **self.tmpl)
 
     @tornado.web.authenticated
@@ -1138,7 +1143,11 @@ class AegisBuild(AegisWeb):
             env = env.rsplit('-', maxsplit=1)[0]
         self.tmpl['live_build'] = aegis.model.Build.get_live_build(env)
         self.tmpl['aegis_version'] = pkg_resources.require("aegis-tools")[0].version
-        self.tmpl['app_version'] = pkg_resources.require(aegis.config.get('program_name'))[0].version
+        try:
+            self.tmpl['app_version'] = pkg_resources.require(aegis.config.get('program_name'))[0].version
+        except pkg_resources.ContextualVersionConflict as ex:
+            logging.exception(ex)
+            self.tmpl['app_version'] = 'N/A'
         return self.render_path("build.html", **self.tmpl)
 
     @tornado.web.authenticated
